@@ -5,58 +5,81 @@ Please extend this file with more lvl=100 shibe wow.
 
 """
 
+import random
+from collections import deque
 
-KNOWN_PROCESSES = (
-    # wow shells and terminals and etc
-    'urxvt', 'tmux', 'fish', 'ssh', 'mutt', 'screen', 'mosh-client',
-    'Terminal', 'sh', 'bash', 'zsh', 'tcsh', 'csh',
 
-    # pretty browsers
-    'chromium', 'luakit', 'uzbl-core', 'firefox', 'jumanji', 'chrome',
-    'thunderbird', 'Safari', 'Google Chrome', 'iceweasel',
+class DogeDeque(deque):
+    """
+    A doge deque. A doqe, if you may.
 
-    # many wms
-    'awesome', 'beryl', 'blackbox', 'bspwm', 'compiz', 'dwm',
-    'enlightenment', 'herbstluftwm', 'fluxbox', 'fvwm', 'i3', 'icewm',
-    'kwin', 'metacity', 'musca', 'openbox', 'pekwm', 'ratpoison',
-    'scrotwm', 'wmaker', 'wmfs', 'wmii', 'xfwm4', 'xmonad',
-    'gnome-shell', 'devilspie2',
+    Because random is random, just using a random choice from the static lists
+    below there will always be some repetition in the output. This collection
+    will instead shuffle the list upon init, and act as a rotating deque
+    whenever an item is gotten from it.
 
-    # such services and daemons
-    'mpd', 'nginx', 'dzen2', 'systemd', 'lighttpd', 'prosody',
-    'mongod', 'postgres', 'mysqld', 'redis-server', 'php-fpm',
-    'sendmail', 'irssi', 'screen', 'neo4j', 'httpd', 'Flux', 'Dropbox',
-    'VirtualBox', 'VirtualBoxVM', 'tmux', 'xflux', 'weechat', 'xen',
-    'apache', 'sshd',
+    """
 
-    # programming languages
-    'ruby', 'python', 'java', 'php', 'node', 'erlang', 'perl',
+    def __init__(self, *args):
+        self.index = 0
+        args = list(args)
+        random.shuffle(args)
+        super(DogeDeque, self).__init__(args)
 
-    # so editors
-    'emacs', 'vim', 'nano', 'gedit', 'sublime_text', 'subl',
+    def get(self):
+        """
+        Get one item. This will rotate the deque one step. Repeated gets will
+        return different items.
 
-    # very talk
-    'HipChat', 'Mail',
+        """
 
-    # wow cluster
-    'pbs_sched', 'pbs_mom', 'mpirun', 'sgeexecd', 'slurmd',
-)
+        self.index += 1
 
-PREFIXES = (
+        # If we've gone through the entire deque once, shuffle it again to
+        # simulate ever-flowing random. self.shuffle() will run __init__(),
+        # which will reset the index to 0.
+        if self.index == len(self):
+            self.shuffle()
+
+        self.rotate(1)
+        return self[0]
+
+    def extend(self, iterable):
+        # Whenever we extend the list, make sure to shuffle in the new items!
+        super(DogeDeque, self).extend(iterable)
+        self.shuffle()
+
+    def shuffle(self):
+        """
+        Shuffle the deque
+
+        Deques themselves do not support this, so this will make all items into
+        a list, shuffle that list, clear the deque, and then re-init the deque.
+
+        """
+
+        args = list(self)
+        random.shuffle(args)
+
+        self.clear()
+        super(DogeDeque, self).__init__(args)
+
+
+PREFIXES = DogeDeque(
     'wow', 'such', 'very', 'so much', 'many', 'lol', 'beautiful',
     'all the', 'the', 'most', 'very much', 'pretty', 'so',
 )
 
 # Please keep in mind that this particular shibe is a terminal hax0r shibe,
 # and the words added should be in that domain
-WORDS = (
+WORDS = DogeDeque(
     'computer', 'hax0r', 'code', 'data', 'internet', 'server',
     'hacker', 'terminal', 'doge', 'shibe', 'program', 'free software',
     'web scale', 'monads', 'git', 'daemon', 'loop', 'pretty', 'uptime',
     'thread safe', 'posix',
 )
 
-SUFFIXES = (
+SUFFIXES = DogeDeque(
     'wow', 'lol', 'hax', 'plz', 'lvl=100'
 )
 
@@ -66,7 +89,7 @@ SUFFIXES = (
 #
 # If you see this and use a light terminal, a pull request with a set that
 # works well on a light terminal would be awesome.
-COLORS = (
+COLORS = DogeDeque(
     23, 24, 25, 26, 27, 29, 30, 31, 32, 33, 35, 36, 37, 38, 39, 41, 42, 43,
     44, 45, 47, 48, 49, 50, 51, 58, 59, 63, 64, 65, 66, 67, 68, 69, 70, 71,
     72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 94,
